Font

Enum Font 

pub enum Font {
Show 16 variants BoldScript, BoldItalic, Bold, BoldSymbol, Fraktur, Script, Monospace, SansSerif, DoubleStruck, DoubleStruckItalic, Italic, BoldFraktur, SansSerifBoldItalic, SansSerifItalic, BoldSansSerif, UpRight,
}
Available font styles from LaTeX.

Variants



BoldScript

The bold and calligraphic font-face.



BoldItalic

The bold and italic font-face.



Bold

The bold font-face.



BoldSymbol

The \boldsymbol font-face: bold italic for characters that are italic by default (Latin letters, lowercase Greek), bold upright for characters that are upright by default (capital Greek, digits).



Fraktur

The fraktur font-face.



Script

The calligraphic font-face.



Monospace

The monospace font-face.



SansSerif

The sans-serif font-face.



DoubleStruck

The double-struck font-face.



DoubleStruckItalic

The double-struck italic font-face. Covers the 5 letters at U+2145–U+2149 (ⅅ, ⅆ, ⅇ, ⅈ, ⅉ); no other characters have double-struck italic forms in Unicode.



Italic

The italic font-face.



BoldFraktur

The bold fraktur font-face.



SansSerifBoldItalic

The bold sans-serif font-face.



SansSerifItalic

The sans-serif italic font-face.



BoldSansSerif

The sans-serif bold font-face.



UpRight

The normal font-face.