Module event

Module event 

The definition of the Event enum, which is used as a logical representation of LaTeX content.

A stream of Result<Event, ParserError>s is produced by the Parser, which can then be typeset/rendered by a renderer. This crate only provides a simple mathml renderer available through the push_mathml and write_mathml functions.

This module tries to be comprehensive in explaining the invariants that are be upheld by the Parser. If a user of this crate, or a renderer implementor finds a case where the invariants are not satisfied, then it is a bug in the parser, and should be reported.

Structs

ColorChange
Represents a color change.
Dimension
Represents a LaTeX dimension.
RelationContent
Sometimes mathematical relations can be made of more than one character, so we need a way to represent them when one character is not enough.

Enums

ArrayColumn
Represents a column in an array environment specification.
ColorTarget
The target of the color change.
ColumnAlignment
Represents a column in a matrix or array environment.
Content
Base events that produce mathml nodes
DelimiterSize
Represents a delimiter size.
DelimiterType
Whether the delimiter is an opening, closing, or fence delimiter.
DimensionUnit
Represents a dimension unit in LaTeX.
EnvironmentFlow
Event
All events that can be produced by the parser.
Font
Available font styles from LaTeX.
Grouping
Represents a grouping of elements, which is itself a single logical element.
Line
Represents a line in a LaTeX environment.
ScriptPosition
Position of the script. This is used to determine how to render the scripts.
ScriptType
Logical type of the script. This is used to determine how to render the scripts.
StateChange
Represents a state change for the following content.
Style
The style of the content.
Visual
Modifies the visual representation of the following element(s)

Type Aliases

Glue
Represents a glue specification.